@@ -180,14 +180,14 @@ def generate_mappings():
 
     ## Conditional tests (only run if something)
     
-    @add_partial('(\S*) exists\? \(if (\S*) is at least (\S*)\)') 
+    @add_partial('(\S*) exists \(if (\S*) is at least (\S*)\)\?') 
     def exist_if_gte(activity, groups):
         if check_value_gte(activity, groups[1], groups[2], True):
             return exist_check(activity, groups[0])
         else:
             return None
 
-    @add_partial('(\S*) or (\S*) exists\? \(if (\S*) is at least (\S*)\)') 
+    @add_partial('(\S*) or (\S*) exists \(if (\S*) is at least (\S*)\)\?') 
     def exist_or_if_gte(activity, groups):
         if check_value_gte(activity, groups[2], groups[3], True):
             return (exist_check(activity, groups[0]) or 
@@ -195,14 +195,14 @@ def generate_mappings():
         else:
             return None
 
-    @add_partial('(\S*) exists\? \(if (\S*) is at least (\S*) and (\S*) is not (\S*)\)') 
+    @add_partial('(\S*) exists \(if (\S*) is at least (\S*) and (\S*) is not (\S*)\)\?') 
     def exist_if_both(activity, groups):
         if (check_value_gte(activity, groups[1], groups[2], True) and not (check_value_is(activity, groups[3], groups[4], False))):
             return exist_check(activity, groups[0])
         else:
             return None
 
-    @add_partial('(\S*) exists\? \(if (\S*) is at least (\S*) and \((\S*) or (\S*) is not (\S*)\)\)') 
+    @add_partial('(\S*) exists \(if (\S*) is at least (\S*) and \((\S*) or (\S*) is not (\S*)\)\)\?') 
     def exist_if_both_or(activity, groups):
         if (check_value_gte(activity, groups[1], groups[2], True) and not (check_value_is(activity, groups[3], groups[5], False) or check_value_is(activity, groups[4], groups[5], False))):
             return exist_check(activity, groups[0])
@@ -210,7 +210,7 @@ def generate_mappings():
             return None
 
 
-    @add_partial('(\S*) or (\S*) exists\? \(if (\S*) is at least (\S*) and \((\S*) or (\S*) is not (\S*)\)\)') 
+    @add_partial('(\S*) or (\S*) exists \(if (\S*) is at least (\S*) and \((\S*) or (\S*) is not (\S*)\)\)\?') 
     def exist_or_if_both(activity, groups):
         if (check_value_gte(activity, groups[2], groups[3], True) and not (check_value_is(activity, groups[4], groups[5], False) or check_value_is(activity, groups[4], groups[5], False))):
             return (exist_check(activity, groups[0]) or 
